@@ -15,6 +15,8 @@ import shlex
 import os
 import platform
 import zipfile
+import signal
+import contextlib
 
 from botocore.compat import six
 #import botocore.compat
@@ -56,6 +58,14 @@ else:
     default_pager = 'less -R'
 
 
+class StdinMissingError(Exception):
+    def __init__(self):
+        message = (
+            'stdin is required for this operation, but is not available.'
+        )
+        super(StdinMissingError, self).__init__(message)
+
+
 class NonTranslatedStdout(object):
     """ This context manager sets the line-end translation mode for stdout.
 
@@ -76,6 +86,7 @@ class NonTranslatedStdout(object):
             import msvcrt
             msvcrt.setmode(sys.stdout.fileno(), self.previous_mode)
 
+
 def ensure_text_type(s):
     if isinstance(s, six.text_type):
         return s
@@ -83,6 +94,7 @@ def ensure_text_type(s):
         return s.decode('utf-8')
     raise ValueError("Expected str, unicode or bytes, received %s." % type(s))
 
+
 if six.PY3:
     import locale
     import urllib.parse as urlparse
@@ -91,7 +103,10 @@ if six.PY3:
 
     raw_input = input
 
-    binary_stdin = sys.stdin.buffer
+    def get_binary_stdin():
+        if sys.stdin is None:
+            raise StdinMissingError()
+        return sys.stdin.buffer
 
     def get_binary_stdout():
         return sys.stdout.buffer
@@ -138,7 +153,10 @@ else:
 
     raw_input = raw_input
 
-    binary_stdin = sys.stdin
+    def get_binary_stdin():
+        if sys.stdin is None:
+            raise StdinMissingError()
+        return sys.stdin
 
     def get_binary_stdout():
         return sys.stdout
@@ -302,3 +320,22 @@ def get_popen_kwargs_for_pager_cmd(pager_cmd=None):
         pager_cmd = shlex.split(pager_cmd)
     popen_kwargs['args'] = pager_cmd
     return popen_kwargs
+
+
+@contextlib.contextmanager
+def ignore_user_entered_signals():
+    """
+    Ignores user entered signals to avoid process getting killed.
+    """
+    if is_windows:
+        signal_list = [signal.SIGINT]
+    else:
+        signal_list = [signal.SIGINT, signal.SIGQUIT, signal.SIGTSTP]
+    actual_signals = []
+    for user_signal in signal_list:
+        actual_signals.append(signal.signal(user_signal, signal.SIG_IGN))
+    try:
+        yield
+    finally:
+        for sig, user_signal in enumerate(signal_list):
+            signal.signal(user_signal, actual_signals[sig])
