@@ -82,6 +82,7 @@ from awscli.customizations.mturk import register_alias_mturk_command
 from awscli.customizations.sagemaker import register_alias_sagemaker_runtime_command
 from awscli.customizations.servicecatalog import register_servicecatalog_commands
 from awscli.customizations.s3events import register_event_stream_arg
+from awscli.customizations.sessionmanager import register_ssm_session
 
 
 def awscli_initialize(event_handlers):
@@ -166,3 +167,4 @@ def awscli_initialize(event_handlers):
     register_history_commands(event_handlers)
     register_event_stream_arg(event_handlers)
     dlm_initialize(event_handlers)
+    register_ssm_session(event_handlers)
